==> haskell-hasql-pool-0.5.0.2-18-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.5.0.2
id: hasql-pool-0.5.0.2-H91xuwM4G0W2CcbfUtNFxn
key: hasql-pool-0.5.0.2-H91xuwM4G0W2CcbfUtNFxn
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
abi: b438fda0918e960c9009d1b4e694d0ab
exposed: True
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-pool-0.5.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-pool-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-pool-0.5.0.2
hs-libraries: HShasql-pool-0.5.0.2-H91xuwM4G0W2CcbfUtNFxn
depends:
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    hasql-1.3.0.3-KMlFVyYtmTM24lcGgFapyO
    resource-pool-0.2.3.2-IAoyPiFBos586Bxmdqt9IZ time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hasql-pool-0.5.0.2-19-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-hasql-pool.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hasql-pool
version: 0.5.0.2
id: hasql-pool-0.5.0.2-8vx5dOlpM6E9snMHDCGQA
key: hasql-pool-0.5.0.2-8vx5dOlpM6E9snMHDCGQA
license: MIT
copyright: (c) 2015, Nikita Volkov
maintainer: Nikita Volkov <nikita.y.volkov@mail.ru>
author: Nikita Volkov <nikita.y.volkov@mail.ru>
homepage: https://github.com/nikita-volkov/hasql-pool
synopsis: A pool of connections for Hasql
category: Hasql, Database, PostgreSQL
abi: 0670548342f1c5a893250c48bf7a950c
exposed: True
exposed-modules:
    Hasql.Pool
hidden-modules: Hasql.Pool.Prelude Hasql.Pool.ResourcePool
import-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-pool-0.5.0.2
library-dirs: /usr/lib/ghc-8.6.5/site-local/hasql-pool-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/hasql-pool-0.5.0.2
hs-libraries: HShasql-pool-0.5.0.2-8vx5dOlpM6E9snMHDCGQA
depends:
    base-prelude-1.3-4ZZNNsW3hao94Bjea11y2s
    hasql-1.3.0.3-8Lchn3Y32ryKVVvAQPnRNi
    resource-pool-0.2.3.2-IAoyPiFBos586Bxmdqt9IZ time-1.8.0.2
haddock-interfaces: /usr/share/doc/haskell-hasql-pool/html/hasql-pool.haddock
haddock-html: /usr/share/doc/haskell-hasql-pool/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
